@@ -2,18 +2,23 @@
 package MooseX::AttributeHelpers::Collection::Array;
 use Moose;
 
-our $VERSION   = '0.17';
-$VERSION = eval $VERSION;
+our $VERSION   = '0.01';
 our $AUTHORITY = 'cpan:STEVAN';
 
-extends 'Moose::Meta::Attribute';
-with 'MooseX::AttributeHelpers::Trait::Collection::Array';
+use MooseX::AttributeHelpers::MethodProvider::Array;
+
+extends 'MooseX::AttributeHelpers::Collection';
+
+has '+method_provider' => (
+    default => 'MooseX::AttributeHelpers::MethodProvider::Array'
+);
+
+sub helper_type { 'ArrayRef' }
 
 no Moose;
 
 # register the alias ...
-package # hide me from search.cpan.org
-    Moose::Meta::Attribute::Custom::Collection::Array;
+package Moose::Meta::Attribute::Custom::Collection::Array;
 sub register_implementation { 'MooseX::AttributeHelpers::Collection::Array' }
 
 
@@ -34,7 +39,7 @@ MooseX::AttributeHelpers::Collection::Array
   use MooseX::AttributeHelpers;
   
   has 'options' => (
-      metaclass => 'Collection::Array',
+      metaclass => 'Collection',
       is        => 'ro',
       isa       => 'ArrayRef[Int]',
       default   => sub { [] },
@@ -54,8 +59,6 @@ for more details.
 
 =over 4
 
-=item B<meta>
-
 =item B<method_provider>
 
 =item B<has_method_provider>
@@ -76,7 +79,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+Copyright 2007 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
