@@ -2,10 +2,6 @@
 package MooseX::AttributeHelpers::Meta::Method::Provided;
 use Moose;
 
-our $VERSION   = '0.17';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 extends 'Moose::Meta::Method';
 
 1;
@@ -22,14 +18,6 @@ MooseX::AttributeHelpers::Meta::Method::Provided
 
 This is an extension of Moose::Meta::Method to mark I<provided> methods.
 
-=head1 METHODS
-
-=over 4
-
-=item B<meta>
-
-=back
-
 =head1 BUGS
 
 All complex software has bugs lurking in it, and this module is no 
@@ -42,11 +30,11 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+Copyright 2007 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
+=cut
\ No newline at end of file
