@@ -2,28 +2,14 @@
 package MooseX::AttributeHelpers::MethodProvider::Counter;
 use Moose::Role;
 
-our $VERSION   = '0.17';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
-sub reset : method {
-    my ($attr, $reader, $writer) = @_;
-    return sub { $writer->($_[0], $attr->default($_[0])) };
-}
-
-sub set : method {
-    my ($attr, $reader, $writer, $value) = @_;
-    return sub { $writer->($_[0], $_[1]) };
-}
-
 sub inc {
-    my ($attr, $reader, $writer) = @_;
-    return sub { $writer->($_[0], $reader->($_[0]) + (defined($_[1]) ? $_[1] : 1) ) };
+    my $attr = shift;
+    return sub { $attr->set_value($_[0], $attr->get_value($_[0]) + 1) };
 }
 
 sub dec {
-    my ($attr, $reader, $writer) = @_;
-    return sub { $writer->($_[0], $reader->($_[0]) - (defined($_[1]) ? $_[1] : 1) ) };
+    my $attr = shift;
+    return sub { $attr->set_value($_[0], $attr->get_value($_[0]) - 1) };        
 }
 
 1;
@@ -53,14 +39,10 @@ L<MooseX::AttributeHelpers::Counter>.
 
 =over 4
 
-=item B<set>
-
 =item B<inc>
 
 =item B<dec>
 
-=item B<reset>
-
 =back
 
 =head1 BUGS
@@ -75,7 +57,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+Copyright 2007 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
