@@ -1,18 +1,52 @@
 package MooseX::AttributeHelpers::Number;
 use Moose;
 
-our $VERSION   = '0.17';
-$VERSION = eval $VERSION;
+our $VERSION   = '0.01';
 our $AUTHORITY = 'cpan:STEVAN';
 
-extends 'Moose::Meta::Attribute';
-with 'MooseX::AttributeHelpers::Trait::Number';
+extends 'MooseX::AttributeHelpers::Base';
 
+sub helper_type { 'Num' }
+
+has '+method_constructors' => (
+    default => sub {
+        return +{
+            set => sub {
+                my $attr = shift;
+                return sub { $attr->set_value($_[0], $_[1]) };
+            },
+            add => sub {
+                my $attr = shift;
+                return sub { $attr->set_value($_[0], $attr->get_value($_[0]) + $_[1]) };
+            },
+            sub => sub {
+                my $attr = shift;
+                return sub { $attr->set_value($_[0], $attr->get_value($_[0]) - $_[1]) };
+            },
+            mul => sub {
+                my $attr = shift;
+                return sub { $attr->set_value($_[0], $attr->get_value($_[0]) * $_[1]) };
+            },
+            div => sub {
+                my $attr = shift;
+                return sub { $attr->set_value($_[0], $attr->get_value($_[0]) / $_[1]) };
+            },
+            mod => sub {
+                my $attr = shift;
+                return sub { $attr->set_value($_[0], $attr->get_value($_[0]) % $_[1]) };
+            },
+            abs => sub {
+                my $attr = shift;
+                return sub { $attr->set_value($_[0], abs($attr->get_value($_[0])) ) };
+            },
+        }
+    }
+);
+    
 no Moose;
 
 # register the alias ...
-package # hide me from search.cpan.org
-    Moose::Meta::Attribute::Custom::Number;
+package Moose::Meta::Attribute::Custom::Number;
 sub register_implementation { 'MooseX::AttributeHelpers::Number' }
 
 1;
@@ -58,51 +92,12 @@ basic math operations.
 
 =over 4
 
-=item B<meta>
-
 =item B<helper_type>
 
 =item B<method_constructors>
 
 =back
 
-=head1 PROVIDED METHODS
-
-It is important to note that all those methods do in place
-modification of the value stored in the attribute.
-
-=over 4
-
-=item I<set ($value)>
-
-Alternate way to set the value.
-
-=item I<add ($value)>
-
-Adds the current value of the attribute to C<$value>.
-
-=item I<sub ($value)>
-
-Subtracts the current value of the attribute to C<$value>.
-
-=item I<mul ($value)>
-
-Multiplies the current value of the attribute to C<$value>.
-
-=item I<div ($value)>
-
-Divides the current value of the attribute to C<$value>.
-
-=item I<mod ($value)>
-
-Modulus the current value of the attribute to C<$value>.
-
-=item I<abs>
-
-Sets the current value of the attribute to its absolute value.
-
-=back
-
 =head1 BUGS
 
 All complex software has bugs lurking in it, and this module is no 
@@ -115,7 +110,7 @@ Robert Boone
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+Copyright 2007 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
